Method for android and iOS
--------------------------

.. autoclass:: atx.device.CommonWrap
    :members:


Method only for android
--------------------------

.. autoclass:: atx.device.AndroidDevice
    :members:

    .. attribute:: serial

        Android device serial number.
